// Class used if the GTN750 instrument is not installed in the community directory
class GTN750_NOGTN750 extends BaseInstrument {
    get templateID() { return "GTN750_INT"; }  // ID if the instrument in HTML
    get instrumentAlias() { return "GTN750"; }
    constructor() {
        super();
    }
    connectedCallback() {
        super.connectedCallback();
    }
}


// Check if the GTN750 instrument is installed 
// We try to read a file of the package in the Virtual file system
let httpRequest = new XMLHttpRequest();
httpRequest.onreadystatechange = function (data) {
    if (this.readyState === XMLHttpRequest.DONE) {
        let loaded = this.status === 200 || this.status === 0;
        if (loaded) {
            // GTN750 is installed
            // Register the instrument
            Include.addScript("/Pms50/gtn750/Pages/VCockpit/Instruments/NavSystems/GPS/GTN750/js/GTN750.js", function () {
                registerInstrument("gtn750-int-element", GTN750_INT);
                // Set a global variable telling we are installed
                SimVar.SetSimVarValue("L:PMS50_GTN750_INSTALLED", "bool", true);
                // Force using the GTN750
                setInterval(() => {
                    SimVar.SetSimVarValue("L:SWAP_PANEL_ALL", "bool", true);
//                    SimVar.SetSimVarValue("L:SWAP_OPEN", "bool", false);
                    SimVar.SetSimVarValue("L:GTN750_INT_HIDDEN", "bool", false);
                    SimVar.SetSimVarValue("L:AS530_HIDDEN", "bool", true);
                }, 1000);
            });
        }
        else {
            // GTN750 is NOT installed
            // Set a global variable telling we are not installed
            SimVar.SetSimVarValue("L:PMS50_GTN750_INSTALLED", "bool", false);
            // Register the fake instrument
            registerInstrument("gtn750-int-element", GTN750_NOGTN750);
        }
    }
};
var milliseconds = new Date().getTime().toString();
httpRequest.open("GET", "/VFS/Integration/gtn750_interface/check.txt?id=" + milliseconds);
httpRequest.send();
